OC.L10N.register(
    "core",
    {
    "Please select a file." : "Selecteer een bestand.",
    "File is too big" : "Bestand te groot",
    "The selected file is not an image." : "Het geselecteerde bestand is geen afbeelding.",
    "The selected file cannot be read." : "Het geselecteerde bestand kan niet worden gelezen.",
    "The file was uploaded" : "Het bestand werd geüpload",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Het geüploade bestand overschrijdt de upload_max_filesize optie in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Het bestand overschrijdt de MAX_FILE_SIZE waarde die is opgegeven in het HTML formulier",
    "The file was only partially uploaded" : "Het bestand is slechts gedeeltelijk geüpload",
    "No file was uploaded" : "Er is geen bestand geüpload",
    "Missing a temporary folder" : "Tijdelijke map ontbreekt",
    "Could not write file to disk" : "Kon bestand niet naar schijf schrijven",
    "A PHP extension stopped the file upload" : "Een PHP-extensie blokkeerde de upload.",
    "Invalid file provided" : "Ongeldig bestand opgegeven",
    "No image or file provided" : "Geen afbeelding of bestand opgegeven",
    "Unknown filetype" : "Onbekend bestandsformaat",
    "An error occurred. Please contact your admin." : "Er trad een fout op. Neem contact op met je beheerder.",
    "Invalid image" : "Afbeelding ongeldig",
    "No temporary profile picture available, try again" : "Geen tijdelijke profielafbeelding beschikbaar. Probeer het opnieuw",
    "No crop data provided" : "Geen bijsnijdingsgegevens opgegeven",
    "No valid crop data provided" : "Geen geldige bijsnijdingsgegevens opgegeven",
    "Crop is not square" : "Bijgesneden afbeelding is niet vierkant",
    "State token does not match" : "State-token komt niet overeen",
    "Invalid app password" : "Ongeldig appwachtwoord",
    "Could not complete login" : "De login kon niet worden voltooid",
    "State token missing" : "Toestandstoken bestaat niet",
    "Your login token is invalid or has expired" : "Je inlogtoken is ongeldig of is vervallen",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Deze community release van Nextcloud wordt niet ondersteund en meldingen zijn beperkt",
    "Login" : "Inloggen",
    "Unsupported email length (>255)" : "Niet ondersteunde e-maillengte (>255)",
    "Password reset is disabled" : "Wachtwoordreset is uitgeschakeld",
    "Could not reset password because the token is expired" : "Kon wachtwoord niet resetten omdat de token verlopen is",
    "Could not reset password because the token is invalid" : "Kon wachtwoord niet resetten omdat de token ongeldig is",
    "Password is too long. Maximum allowed length is 469 characters." : "Wachtwoord is te lang. Maximum toegestane lengte is 469 karakters.",
    "%s password reset" : "%s reset wachtwoord",
    "Password reset" : "Wachtwoordreset",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Klik op de volgende knop om je wachtwoord te resetten. Als je geen wachtwoordreset hebt aangevraagd, negeer dan dit e-mailbericht.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Klik op de volgende link om je wachtwoord te resetten. Als je geen wachtwoordherstel hebt aangevraagd, negeer dan dit e-mailbericht.",
    "Reset your password" : "Reset je wachtwoord",
    "The given provider is not available" : "De opgegeven provider is niet beschikbaar",
    "Task not found" : "Taak niet gevonden",
    "Internal error" : "Interne fout",
    "Not found" : "Niet gevonden",
    "Bad request" : "Ongeldige aanvraag",
    "Requested task type does not exist" : "Het aangevraagde taaktype bestaat niet",
    "Necessary language model provider is not available" : "De nodige taalmodel provider is niet beschikbaar",
    "No text to image provider is available" : "Geen text naar afbeelding aanbieder beschikbaar",
    "Image not found" : "Afbeelding niet gevonden",
    "No translation provider available" : "Geen provider voor vertaling beschikbaar",
    "Could not detect language" : "Kan taal niet detecteren",
    "Unable to translate" : "Niet mogelijk te vertalen",
    "Nextcloud Server" : "Nextcloud Server",
    "Some of your link shares have been removed" : "Sommige van je gedeelde links zijn verwijderd",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Door een security-bug moesten we sommige van je gedeelde links verwijderen. Bekijk de link voor meer informatie.",
    "The account limit of this instance is reached." : "De accountlimiet van deze instantie is bereikt.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Voer uw abonnementscode in de support-app in om de accountlimiet te verhogen. Dit geeft u ook alle extra voordelen die Nextcloud Enterprise biedt en wordt ten zeerste aanbevolen voor gebruik binnen bedrijven.",
    "Learn more ↗" : "Meer weten ↗",
    "Preparing update" : "Update voorbereiden",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Herstel stap:",
    "Repair info:" : "Herstel informatie:",
    "Repair warning:" : "Herstel waarschuwing:",
    "Repair error:" : "Herstel fout:",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Gelieve de commandolijn updater te gebruiken omdat bijwerken via de browser is uitgeschakeld in uw config.php.",
    "Turned on maintenance mode" : "Onderhoudsmodus ingeschakeld",
    "Turned off maintenance mode" : "Onderhoudsmodus uitgeschakeld",
    "Maintenance mode is kept active" : "Onderhoudsmodus blijft actief",
    "Updating database schema" : "Databaseschema aan het bijwerken",
    "Updated database" : "Database bijgewerkt",
    "Update app \"%s\" from App Store" : "Update app \"%s\" vanuit de App Store",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Controleert of het databaseschema voor %s geüpdatet kan worden (dit kan lang duren afhankelijk van de grootte van de database)",
    "Updated \"%1$s\" to %2$s" : "Werkte \"%1$s\" bij tot %2$s",
    "Set log level to debug" : "Debug logniveau instellen",
    "Reset log level" : "Terugzetten logniveau",
    "Starting code integrity check" : "Starten code betrouwbaarheidscontrole",
    "Finished code integrity check" : "Code betrouwbaarheidscontrole beeindigd",
    "%s (incompatible)" : "%s (incompatibel)",
    "The following apps have been disabled: %s" : "De volgende apps zijn uitgeschakeld: %s",
    "Already up to date" : "Al bijgewerkt",
    "Error occurred while checking server setup" : "Een fout trad op bij controleren van serverconfiguratie",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Voor meer informatie word je verwezen naar de {linkstart}documentatie↗{linkend}.",
    "unknown text" : "onbekende tekst",
    "Hello world!" : "Hallo wereld!",
    "sunny" : "zonnig",
    "Hello {name}, the weather is {weather}" : "Hallo {name}, het is hier {weather}",
    "Hello {name}" : "Hallo {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dit zijn je zoekresultaten<script>alert(1)</script></strong>",
    "new" : "nieuw",
    "_download %n file_::_download %n files_" : ["download %n bestand","download %n bestanden"],
    "The update is in progress, leaving this page might interrupt the process in some environments." : "De update is bezig, deze pagina verlaten kan het updateproces in sommige omgevingen onderbreken.",
    "Update to {version}" : "Geüpdatet naar {version}",
    "An error occurred." : "Er heeft zich een fout voorgedaan.",
    "Please reload the page." : "Herlaad deze pagina.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "De update was niet succesvol. Voor meer informatie <a href=\"{url}\">zie ons bericht op het forum</a> over dit probleem.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "De update is mislukt. Meld dit probleem aan de <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>.",
    "Continue to {productName}" : "Verder naar {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["De update was succesvol. Redirecten naar {productName} over %nseconde.","De update was succesvol. Redirecten naar {productName} over %n seconden."],
    "Applications menu" : "Applicatiemenu",
    "Apps" : "Apps",
    "More apps" : "Meer apps",
    "_{count} notification_::_{count} notifications_" : ["{count} melding","{count} meldingen"],
    "No" : "Nee",
    "Yes" : "Ja",
    "The remote URL must include the user." : "De externe URL moet de gebruiker bevatten.",
    "Invalid remote URL." : "Ongeldige externe URL.",
    "Failed to add the public link to your Nextcloud" : "Kon de openbare link niet aan je Nextcloud toevoegen",
    "Federated user" : "Gefedereerde gebruiker",
    "user@your-nextcloud.org" : "gebruiker@your-nextcloud.org",
    "Create share" : "Creëren share",
    "Direct link copied to clipboard" : "Directe link gekopieerd naar klembord",
    "Please copy the link manually:" : "Kopieer de link handmatig:",
    "Custom date range" : "Aangepast datumbereik",
    "Pick start date" : "Kies startdatum",
    "Pick end date" : "Kies einddatum",
    "Search in date range" : "In datumbereik zoeken",
    "Search in current app" : "Zoek in huidige app",
    "Clear search" : "Wis zoekvak",
    "Search everywhere" : "Zoek in alles",
    "Searching …" : "Zoeken ...",
    "Start typing to search" : "Begin met typen om te zoeken",
    "No matching results" : "Geen resultaten",
    "Today" : "Vandaag",
    "Last 7 days" : "Laatste 7 dagen",
    "Last 30 days" : "Laatste 30 dagen",
    "This year" : "Dit jaar",
    "Last year" : "Vorig jaar",
    "Unified search" : "Geünificeerd zoeken",
    "Search apps, files, tags, messages" : "Zoek apps, bestanden, berichten",
    "Places" : "Locaties",
    "Date" : "Datum",
    "Search people" : "Zoek mensen",
    "People" : "Mensen",
    "Filter in current view" : "Beperk tot huidige weergave",
    "Results" : "Resultaten",
    "Load more results" : "Laad meer resultaten",
    "Search in" : "Zoek in",
    "Log in" : "Inloggen",
    "Logging in …" : "Inloggen...",
    "Log in to {productName}" : "Inloggen bij {productName}",
    "Wrong login or password." : "Verkeerde login of wachtwoord.",
    "This account is disabled" : "Dit account is uitgeschakeld",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "We hebben meerdere foutieve inlogverzoeken vanaf jouw IP-adres gedetecteerd. Hierdoor wordt je volgende inlogverzoek 30 seconden uitgesteld.",
    "Account name or email" : "Gebruikersnaam of email",
    "Account name" : "Accountnaam",
    "Server side authentication failed!" : "Authenticatie bij de server mislukt!",
    "Please contact your administrator." : "Neem contact op met je systeembeheerder.",
    "An internal error occurred." : "Er heeft zich een interne fout voorgedaan.",
    "Please try again or contact your administrator." : "Probeer het opnieuw of neem contact op met je beheerder.",
    "Password" : "Wachtwoord",
    "Log in with a device" : "Inloggen met een apparaat",
    "Login or email" : "Login of email",
    "Your account is not setup for passwordless login." : "Je account is niet ingesteld voor inloggen zonder wachtwoord.",
    "Your connection is not secure" : "Je verbinding is niet veilig",
    "Passwordless authentication is only available over a secure connection." : "Inloggen zonder wachtwoord is alleen mogelijk over een beveiligde verbinding.",
    "Browser not supported" : "Browser niet ondersteund",
    "Passwordless authentication is not supported in your browser." : "Inloggen zonder wachtwoord is niet ondersteund door je browser.",
    "Reset password" : "Reset wachtwoord",
    "Back to login" : "Terug naar inloggen",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Als dit account bestaat, werd er een wachtwoordherstel email naar het overeenkomstige email adres gestuurd. Krijg je geen mail? Controleer dan het e-mailadres en/of de login, check je spam folder of vraag hulp aan je  beheerder.",
    "Couldn't send reset email. Please contact your administrator." : "Kon herstel email niet versturen. Neem contact op met je beheerder.",
    "Password cannot be changed. Please contact your administrator." : "Het wachtwoord kan niet worden gewijzigd. Neem contact op met je beheerder.",
    "New password" : "Nieuw wachtwoord",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Je bestanden zijn versleuteld. Het is niet mogelijk om je gegevens terug te krijgen als je wachtwoord wordt gereset. Als je niet zeker weer wat je moet doen, neem dan contact op met je beheerder voordat je verdergaat. Wil je echt verder gaan?",
    "I know what I'm doing" : "Ik weet wat ik doe",
    "Resetting password" : "Resetten wachtwoord",
    "Schedule work & meetings, synced with all your devices." : "Plan je werk & afspraken, gesynced met al je toestellen.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Bewaar je collega's en vrienden op één plaats zonder hun persoonlijke gegevens te laten uitlekken.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Simpele e-mailapp, handig geïntegreerd met Bestanden, Contactpersonen en Agenda.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatten, videobellen, schermdelen, online vergaderingen en webconferenties - in de browser en met mobiele apps.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Samenwerken aan tekst, spreadsheets en presentaties, gebouwt op basis van Collabora Online.",
    "Distraction free note taking app." : "Notitie app zonder afleiding.",
    "Recommended apps" : "Aanbevolen apps",
    "Loading apps …" : "Laden apps ...",
    "Could not fetch list of apps from the App Store." : "Kon lijst met apps niet ophalen vanuit de App Store.",
    "App download or installation failed" : "App download of installatie mislukt",
    "Cannot install this app because it is not compatible" : "Kan deze app niet installeren omdat deze niet compatible is",
    "Cannot install this app" : "Kan deze app niet installeren",
    "Skip" : "Overslaan",
    "Installing apps …" : "Installeren apps …",
    "Install recommended apps" : "Installeer aanbevolen apps",
    "Avatar of {displayName}" : "Avatar van {displayName}",
    "Settings menu" : "Instellingenmenu",
    "Loading your contacts …" : "Je contacten wordt geladen ...",
    "Looking for {term} …" : "Kijken voor {term} …",
    "Search contacts" : "Zoek contacten",
    "Reset search" : "Zoekopdracht wissen",
    "Search contacts …" : "Zoek contacten ...",
    "Could not load your contacts" : "Kon je contactpersonenen niet laden",
    "No contacts found" : "Geen contacten gevonden",
    "Show all contacts" : "Toon alle contactpersonen",
    "Install the Contacts app" : "Installeer de Contacts app",
    "Search" : "Zoeken",
    "No results for {query}" : "Geen resultaten voor {query}",
    "Press Enter to start searching" : "Druk op Enter om te beginnen zoeken",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Voer {minSearchLength} tekens of meer in om te zoeken","Voer alstublieft {minSearchLength} tekens of meer in om te zoeken"],
    "An error occurred while searching for {type}" : "Er trad een fout op bij het zoeken naar {type}",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Het zoeken begint wanneer je begint met typen en resultaten kunnen geselecteerd worden met de pijltjestoetsen",
    "Search for {name} only" : "Zoek alleen naar {name}",
    "Loading more results …" : "Meer resultaten laden ...",
    "Forgot password?" : "Wachtwoord vergeten?",
    "Back to login form" : "Terug naar aanmelden",
    "Back" : "Terug",
    "Login form is disabled." : "Inlogscherm uitgeschakeld",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Het aanmeldingsformulier van Nextcloud is uitgeschakeld. Gebruik een andere inlogmogelijkheid indien beschikbaar of neem contact op met uw beheerder.",
    "More actions" : "Meer acties",
    "Security warning" : "Beveiligingswaarschuwing",
    "Storage & database" : "Opslag & database",
    "Data folder" : "Gegevensmap",
    "Install and activate additional PHP modules to choose other database types." : "Installeer en activeer aanvullende PHP modules om andere soorten databases te kiezen.",
    "For more details check out the documentation." : "Voor meer informatie word je verwezen naar de documentatie.",
    "Performance warning" : "Prestatiewaarschuwing",
    "You chose SQLite as database." : "Je koos SQLite als database.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite zou alleen moeten worden gebruikt voor minimale en ontwikkelomgevingen. Voor productie raden we aan om een andere database backend te gebruiken.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Als je clients gebruikt voor bestandssynchronisatie wordt het gebruik van SQLite sterk ontraden.",
    "Database user" : "Gebruiker database",
    "Database password" : "Wachtwoord database",
    "Database name" : "Naam database",
    "Database tablespace" : "Database tablespace",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Geef het poortnummer en servernaam op (bijv. localhost:5432).",
    "Database host" : "Databaseserver",
    "Installing …" : "Installeren …",
    "Install" : "Installeren",
    "Need help?" : "Hulp nodig?",
    "See the documentation" : "Zie de documentatie",
    "{name} version {version} and above" : "{name} versie {version} en hoger",
    "This browser is not supported" : "Deze browser wordt niet ondersteunt",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Deze browser wordt niet ondersteunt. Upgrade a.u.b naar een nieuwere versie of een browser die wel ondersteunt wordt.",
    "Continue with this unsupported browser" : "Ga verder met deze niet-ondersteunde browser",
    "Supported versions" : "Ondersteunde versies",
    "Search {types} …" : "Zoeken naar {types}…",
    "Choose {file}" : "Kies {file}",
    "Choose" : "Kies",
    "Copy to {target}" : "Kopieer naar {target}",
    "Copy" : "Kopiëren",
    "Move to {target}" : "Verplaats naar {target}",
    "Move" : "Verplaatsen",
    "OK" : "OK",
    "read-only" : "Alleen lezen",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} bestandsconflict","{count} bestandsconflicten"],
    "One file conflict" : "Een bestandsconflict",
    "New Files" : "Nieuwe bestanden",
    "Already existing files" : "Al aanwezige bestanden",
    "Which files do you want to keep?" : "Welke bestanden wil je bewaren?",
    "If you select both versions, the copied file will have a number added to its name." : "Als je beide versies selecteert, zal het gekopieerde bestand een nummer aan de naam toegevoegd krijgen.",
    "Cancel" : "Annuleren",
    "Continue" : "Verder",
    "(all selected)" : "(alles geselecteerd)",
    "({count} selected)" : "({count} geselecteerd)",
    "Error loading file exists template" : "Fout bij laden bestand bestaat al sjabloon",
    "Saving …" : "Opslaan ...",
    "seconds ago" : "seconden geleden",
    "Connection to server lost" : "Verbinding met server verbroken",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Probleem met laden pagina, herladen over %n seconde","Probleem met laden pagina, herladen over %n seconden"],
    "Add to a project" : "Toevoegen aan een project",
    "Show details" : "Bekijk details",
    "Hide details" : "Verberg details",
    "Rename project" : "Hernoem project",
    "Failed to rename the project" : "Hernoemen van project is mislukt",
    "Failed to create a project" : "Aanmaken van project is mislukt",
    "Failed to add the item to the project" : "Item toevoegen aan project mislukt",
    "Connect items to a project to make them easier to find" : "Verbind items aan een project om ze eenvoudiger terug te vinden",
    "Type to search for existing projects" : "Type om bestaande projecten te vinden",
    "New in" : "Nieuw in",
    "View changelog" : "Bekijk wijzigingsoverzicht",
    "No action available" : "Geen actie beschikbaar",
    "Error fetching contact actions" : "Fout bij ophalen contact acties",
    "Close \"{dialogTitle}\" dialog" : "Sluit \"{dialogTitle}\" dialoog",
    "Email length is at max (255)" : "E-maillengte is op maximum (255)",
    "Non-existing tag #{tag}" : "Niet bestaande markering #{tag}",
    "Restricted" : "Beperkt",
    "Invisible" : "Onzichtbaar",
    "Delete" : "Verwijder",
    "Rename" : "Naam wijzigen",
    "Collaborative tags" : "Systeemtags",
    "No tags found" : "Geen tags gevonden",
    "Clipboard not available, please copy manually" : "Klembord niet beschikbaar, kopieer handmatig a.u.b.",
    "Personal" : "Persoonlijk",
    "Accounts" : "Accounts",
    "Admin" : "Beheerder",
    "Help" : "Help",
    "Access forbidden" : "Toegang verboden",
    "Page not found" : "Pagina niet gevonden",
    "The page could not be found on the server or you may not be allowed to view it." : "Deze pagina kan niet worden gevonden op de server, of je hebt geen toelating om ze te bekijken.",
    "Back to %s" : "Terug naar %s",
    "Too many requests" : "Te veel aanvragen",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Er waren te veel aanvragen afkomstig uit uw netwerk. Probeer later opnieuw of contacteer de beheerder als dat niet correct is.",
    "Error" : "Fout",
    "Internal Server Error" : "Interne serverfout",
    "The server was unable to complete your request." : "De server was niet in staat je aanvraag te verwerken.",
    "If this happens again, please send the technical details below to the server administrator." : "Stuur de hieronder afgebeelde technische details naar de serverbeheerder wanneer dit opnieuw gebeurt.",
    "More details can be found in the server log." : "Meer details in de serverlogging,",
    "For more details see the documentation ↗." : "Voor meer details zie de documentatie ↗.",
    "Technical details" : "Technische details",
    "Remote Address: %s" : "Extern adres: %s",
    "Request ID: %s" : "Aanvraag ID: %s",
    "Type: %s" : "Type: %s",
    "Code: %s" : "Code: %s",
    "Message: %s" : "Boodschap: %s",
    "File: %s" : "Bestand: %s",
    "Line: %s" : "Regel: %s",
    "Trace" : "Trace",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Het lijkt erop of je Nextcloud wilt herinstalleren. Maar het bestand CAN_INSTALL ontbreekt in de configdirectory. Maak het bestand CAN_INSTALL aan in je config map om verder te gaan.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Kon CAN_INSTALL niet verwijderen uit de config map. Verwijder het bestand handmatig.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Deze applicatie heeft JavaScript nodig. {linkstart}Activeer JavaScript{linkend} en ververs deze pagina.",
    "Skip to main content" : "Ga naar hoofdinhoud",
    "Skip to navigation of app" : "Ga naar navigatie van app",
    "Go to %s" : "Ga naar %s",
    "Get your own free account" : "Maak je eigen gratis account",
    "Connect to your account" : "Verbind jouw account",
    "Please log in before granting %1$s access to your %2$s account." : "Eerst inloggen voordat je %1$s toegang geeft tot je %2$s account.",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Als u geen nieuw apparaat of nieuwe app probeert in te stellen, probeert iemand je te misleiden om hem toegang tot je gegevens te verlenen. Ga in dat geval niet verder en neem in plaats daarvan contact op met je systeembeheerder.",
    "App password" : "App wachtwoord",
    "Grant access" : "Verleen toegang",
    "Alternative log in using app password" : "Alternatieve login met app wachtwoord",
    "Account access" : "Account toegang",
    "Currently logged in as %1$s (%2$s)." : "Ingelogd als %1$s (%2$s).",
    "You are about to grant %1$s access to your %2$s account." : "Je staat op het punt om %1$s toegang te verlenen tot je %2$s account.",
    "Account connected" : "Account verbonden",
    "Your client should now be connected!" : "Je client zou nu moeten verbonden zijn!",
    "You can close this window." : "Je mag dit venster sluiten.",
    "Previous" : "Vorige",
    "This share is password-protected" : "Deze share is wachtwoordbeveiligd",
    "The password is wrong or expired. Please try again or request a new one." : "Het paswoord is fout of vervallen. Probeer opnieuw of vraag er een nieuw aan.",
    "Please type in your email address to request a temporary password" : "Geef a.u.b uw email-adres op om een tijdelijk wachtwoord aan te vragen.",
    "Email address" : "E-mailadres",
    "Password sent!" : "Wachtwoord verzonden!",
    "You are not authorized to request a password for this share" : "U bent niet geauthoriseerd om een wachtwoord aan te vragen voor deze instantie",
    "Two-factor authentication" : "Tweefactor authenticatie",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Versterkte beveiliging is ingeschakeld voor je account. Kies een tweede factor voor authenticatie:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Kon niet minimaal één van je ingeschakelde twee-factor auth methoden laden. Neem contact op met je beheerder.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Tweefactor authenticatie is ingeschakeld, maar niet geconfigureerd voor je account. Neem voor hulp contact op met je beheerder.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Tweefactor authenticatie is ingeschakeld, maar niet geconfigureerd voor je account. Ga verder met instellen van tweefactor authenticatie.",
    "Set up two-factor authentication" : "Instellen tweefactor authenticatie",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Tweefactor authenticatie is ingeschakeld, maar niet geconfigureerd voor je account. Gebruik een van je backup codes om in te loggen of neem voor hulp contact op met je beheerder.",
    "Use backup code" : "Gebruik back-upcode",
    "Cancel login" : "Inlog annuleren",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Versterkte beveiliging is ingeschakeld voor je account. Kies een provider om in te stellen:",
    "Error while validating your second factor" : "Fout bij het verifiëren van je tweede factor",
    "Access through untrusted domain" : "Toegang via een niet vertrouwd domein",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Neem contact op met je beheerder. Wanneer je een beheerder bent kun je de \"trusted_domains\" instelling bewerken in config/config.php zoals in het voorbeeld config.sample.php. ",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Verdere informatie over hoe je dit instelt staat in de %1$s documentatie  %2$s.",
    "App update required" : "Bijwerken App vereist",
    "%1$s will be updated to version %2$s" : "%1$s wordt bijgewerkt naar versie %2$s",
    "The following apps will be updated:" : "Deze apps worden bijgewerkt:",
    "These incompatible apps will be disabled:" : "De volgende incompatibele apps worden uitgeschakeld:",
    "The theme %s has been disabled." : "Het thema %s is uitgeschakeld.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Let erop dat de database, de config-map en de data-map zijn geback-upt voordat je verder gaat.",
    "Start update" : "Begin de update",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Om time-outs tijdens grotere installaties te voorkomen, kun je in plaats hiervan de volgende opdracht geven vanaf je installatiedirectory:",
    "Detailed logs" : "Gedetailleerde logs",
    "Update needed" : "Update vereist",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Gebruik alsjeblieft de commandoregel updater omdat je een installatie hebt met meer dan 50 gebruikers.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Bekijk de <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentatie</a> voor hulp.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "De update via de web UI heeft risico's. Het verzoek leidt mogelijk tot een time-out en kan tot verlies van gegevens leiden. Ik heb een back-up gemaakt en weet hoe deze te herstellen in het geval van een update mislukking.",
    "Upgrade via web on my own risk" : "Web opwaarding is op eigen risico",
    "Maintenance mode" : "Onderhoudsmodus",
    "This %s instance is currently in maintenance mode, which may take a while." : "Deze %s staat momenteel in de onderhoudsstand, dat kan enige tijd duren.",
    "This page will refresh itself when the instance is available again." : "Deze pagina wordt ververst als de server weer beschikbaar is.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Neem contact op met je systeembeheerder als deze melding aanhoudt of onverwacht verscheen.",
    "Currently open" : "Momenteel actief",
    "Login with username or email" : "Aanmelden met gebruikersnaam of e-mail",
    "Login with username" : "Aanmelden met gebruikersnaam",
    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatten, videobellen, schermdelen, online vergaderingen en webconferenties - in de browser en met mobiele apps.",
    "You have not added any info yet" : "Je hebt nog geen info toegevoegd",
    "{user} has not added any info yet" : "{user} heeft nog geen info toegevoegd",
    "Error opening the user status modal, try hard refreshing the page" : "Fout bij het openen van het gebruiker status model, probeer een harde refresh van de pagina",
    "Edit Profile" : "Wijzig Profiel",
    "The headline and about sections will show up here" : "De koplijn- en oversectie zal hier verschijnen",
    "Error loading message template: {error}" : "Fout bij laden berichtensjabloon: {error}",
    "Very weak password" : "Zeer zwak wachtwoord",
    "Weak password" : "Zwak wachtwoord",
    "So-so password" : "Matig wachtwoord",
    "Good password" : "Goed wachtwoord",
    "Strong password" : "Sterk wachtwoord",
    "Profile not found" : "Profiel niet gevonden",
    "The profile does not exist." : "Het profiel bestaat niet.",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Je gegevensdirectory en bestanden zijn vermoedelijk bereikbaar vanaf het internet, omdat het .htaccess-bestand niet functioneert.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Bekijk de <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentatie</a> voor Informatie over het correct configureren van je server.",
    "<strong>Create an admin account</strong>" : "<strong>Maak een admin account aan</strong>",
    "New admin account name" : "Nieuwe admin account naam",
    "New admin password" : "Nieuw admin wachtwoord",
    "Show password" : "Toon wachtwoord",
    "Toggle password visibility" : "Omschakelen zichtbaarheid wachtwoord",
    "Configure the database" : "Configureer de database",
    "Only %s is available." : "Alleen %s is beschikbaar.",
    "Database account" : "Database account"
},
"nplurals=2; plural=(n != 1);");
